==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMware to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'VMwareToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 * @property vmwareFabricArmId Gets or sets the ARM Id of the source VMware fabric.
 */
public data class VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
    public val vmwareFabricArmId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 }))
            .vmwareFabricArmId(vmwareFabricArmId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    private var vmwareFabricArmId: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("dhkrrnumtmelffgi")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("asqrwuqfpnfoladm")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("mspjxyapepamjurf")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("cdqgyghqtggqfnge")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source VMware fabric.
     */
    @JvmName("viybrdjxgvkjjjye")
    public suspend fun vmwareFabricArmId(`value`: Output<String>) {
        this.vmwareFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("rfculqextkqakbng")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("nhkkgcvsdjxkvvww")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("rvxitpawvgrxiyrf")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("cuattfjuyabhrxdv")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source VMware fabric.
     */
    @JvmName("hamafdceyngvpvli")
    public suspend fun vmwareFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmwareFabricArmId = mapped
    }

    internal fun build(): VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
            vmwareFabricArmId = vmwareFabricArmId ?: throw PulumiNullFieldException("vmwareFabricArmId"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMware to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'VMwareToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 * @property vmwareFabricArmId Gets or sets the ARM Id of the source VMware fabric.
 */
public data class VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
    public val vmwareFabricArmId: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 }))
            .vmwareFabricArmId(vmwareFabricArmId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    private var vmwareFabricArmId: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("kkqemtjerqvdipvn")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("mslhrifejjyicdmb")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("qobxtouvxtpleraf")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("htgmlcbwncksbgsk")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source VMware fabric.
     */
    @JvmName("cfpsmkqqowohovsc")
    public suspend fun vmwareFabricArmId(`value`: Output<String>) {
        this.vmwareFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("plerqofahdmsspcq")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'VMwareToAzStackHCI'.
     */
    @JvmName("jvpmqfnuxdlcfhca")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("jaekxrabkcagspcb")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("umpplfjkiepwwrgo")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source VMware fabric.
     */
    @JvmName("tcsgijpgpuhiadhf")
    public suspend fun vmwareFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmwareFabricArmId = mapped
    }

    internal fun build(): VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        VMwareToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
            vmwareFabricArmId = vmwareFabricArmId ?: throw PulumiNullFieldException("vmwareFabricArmId"),
        )
}
